@@ -20,6 +20,8 @@ class HexadecimalByteCodec : public ValueCodec
 {
 public:
     explicit HexadecimalByteCodec(bool lowerCaseDigits = false);
+    HexadecimalByteCodec(const HexadecimalByteCodec&) = delete;
+    HexadecimalByteCodec& operator=(const HexadecimalByteCodec&) = delete;
 
 public:
     bool setLowerCaseDigits(bool lowerCaseDigits);
