@@ -23,8 +23,12 @@ class RemovePieceTableChange : public AbstractPieceTableChange
 {
 public:
     RemovePieceTableChange(const AddressRange& removeRange, const PieceList& removedPieces);
+    RemovePieceTableChange(const RemovePieceTableChange&) = delete;
+
     ~RemovePieceTableChange() override;
 
+    RemovePieceTableChange& operator=(const RemovePieceTableChange&) = delete;
+
 public: // AbstractPieceTableChange API
     int type() const override;
     QString description() const override;
