@@ -90,6 +90,11 @@ BookmarksController::~BookmarksController() = default;
 
 void BookmarksController::setTargetModel(AbstractModel* model)
 {
+    ByteArrayView* const byteArrayView = model ? model->findBaseModel<ByteArrayView*>() : nullptr;
+    if (byteArrayView == mByteArrayView) {
+        return;
+    }
+
     if (mByteArrayView) {
         mByteArrayView->disconnect(this);
     }
@@ -97,8 +102,9 @@ void BookmarksController::setTargetModel(AbstractModel* model)
         mByteArray->disconnect(this);
     }
 
-    mByteArrayView = model ? model->findBaseModel<ByteArrayView*>() : nullptr;
+    mByteArrayView = byteArrayView;
 
+    // TODO; check if already same document used before
     ByteArrayDocument* document =
         mByteArrayView ? qobject_cast<ByteArrayDocument*>(mByteArrayView->baseModel()) : nullptr;
     mByteArray = document ? document->content() : nullptr;
@@ -144,7 +150,7 @@ void BookmarksController::updateBookmarks()
         return;
     }
 
-    const int startOffset = mByteArrayView->startOffset();
+    const Okteta::Address startOffset = mByteArrayView->startOffset();
     Okteta::OffsetFormat::print printFunction =
         Okteta::OffsetFormat::printFunction((Okteta::OffsetFormat::Format)mByteArrayView->offsetCoding());
 
@@ -176,7 +182,7 @@ void BookmarksController::updateBookmarks()
 void BookmarksController::onBookmarksAdded(const QVector<Okteta::Bookmark>& bookmarks)
 {
     Q_UNUSED(bookmarks)
-    const int currentPosition = mByteArrayView->cursorPosition();
+    const Okteta::Address currentPosition = mByteArrayView->cursorPosition();
     onCursorPositionChanged(currentPosition);
 
     const int bookmarksCount = mBookmarks->bookmarksCount();
@@ -190,7 +196,7 @@ void BookmarksController::onBookmarksAdded(const QVector<Okteta::Bookmark>& book
 void BookmarksController::onBookmarksRemoved(const QVector<Okteta::Bookmark>& bookmarks)
 {
     Q_UNUSED(bookmarks)
-    const int currentPosition = mByteArrayView->cursorPosition();
+    const Okteta::Address currentPosition = mByteArrayView->cursorPosition();
     onCursorPositionChanged(currentPosition);
 
     const int bookmarksCount = mBookmarks->bookmarksCount();
@@ -228,7 +234,7 @@ void BookmarksController::onCursorPositionChanged(Okteta::Address newPosition)
 
 void BookmarksController::createBookmark()
 {
-    const int cursorPosition = mByteArrayView->cursorPosition();
+    const Okteta::Address cursorPosition = mByteArrayView->cursorPosition();
 
     // search for text at cursor
     const Okteta::CharCodec* charCodec = Okteta::CharCodec::createCodec(mByteArrayView->charCodingName());
@@ -253,7 +259,7 @@ void BookmarksController::createBookmark()
     bookmarkEditPopup->open();
 }
 
-void BookmarksController::addBookmark(int cursorPosition, const QString& name)
+void BookmarksController::addBookmark(Okteta::Address cursorPosition, const QString& name)
 {
     Okteta::Bookmark bookmark(cursorPosition);
     bookmark.setName(name);
@@ -264,7 +270,7 @@ void BookmarksController::addBookmark(int cursorPosition, const QString& name)
 
 void BookmarksController::deleteBookmark()
 {
-    const int cursorPosition = mByteArrayView->cursorPosition();
+    const Okteta::Address cursorPosition = mByteArrayView->cursorPosition();
     const QVector<Okteta::Bookmark> bookmarks { cursorPosition };
     mBookmarks->removeBookmarks(bookmarks);
 }
@@ -276,31 +282,31 @@ void BookmarksController::deleteAllBookmarks()
 
 void BookmarksController::gotoNextBookmark()
 {
-    const int positionAfter = mByteArrayView->cursorPosition() + 1;
+    const Okteta::Address positionAfter = mByteArrayView->cursorPosition() + 1;
 
     Okteta::BookmarksConstIterator bookmarksIterator = mBookmarks->createBookmarksConstIterator();
     const bool hasNext = bookmarksIterator.findNextFrom(positionAfter);
     if (hasNext) {
-        const int newPosition = bookmarksIterator.next().offset();
+        const Okteta::Address newPosition = bookmarksIterator.next().offset();
         mByteArrayView->setCursorPosition(newPosition);
     }
 }
 
 void BookmarksController::gotoPreviousBookmark()
 {
-    const int positionBefore = mByteArrayView->cursorPosition() - 1;
+    const Okteta::Address positionBefore = mByteArrayView->cursorPosition() - 1;
 
     Okteta::BookmarksConstIterator bookmarksIterator = mBookmarks->createBookmarksConstIterator();
     const bool hasPrevious = bookmarksIterator.findPreviousFrom(positionBefore);
     if (hasPrevious) {
-        const int newPosition = bookmarksIterator.previous().offset();
+        const Okteta::Address newPosition = bookmarksIterator.previous().offset();
         mByteArrayView->setCursorPosition(newPosition);
     }
 }
 
 void BookmarksController::onBookmarkTriggered(QAction* action)
 {
-    const int newPosition = action->data().toInt();
+    const Okteta::Address newPosition = action->data().toInt();
     mByteArrayView->setCursorPosition(newPosition);
 }
 
