@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Kasten module, made within the KDE community.
 
-    SPDX-FileCopyrightText: 2009 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2009, 2022 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -18,6 +18,7 @@ class AbstractByteArrayChecksumParameterSet;
 namespace Okteta {
 class AbstractByteArrayModel;
 }
+class KConfigGroup;
 class QString;
 
 class AbstractByteArrayChecksumAlgorithm : public QObject
@@ -28,7 +29,7 @@ protected:
     static constexpr int CalculatedByteCountSignalLimit = 10000;
 
 protected:
-    explicit AbstractByteArrayChecksumAlgorithm(const QString& name);
+    explicit AbstractByteArrayChecksumAlgorithm(const QString& name, const QString& id);
 
 public:
     ~AbstractByteArrayChecksumAlgorithm() override;
@@ -37,9 +38,12 @@ public: // API to be implemented
     virtual bool calculateChecksum(QString* result, const Okteta::AbstractByteArrayModel* model, const Okteta::AddressRange& range) const = 0;
     /** used by the editor to get write access to the parameters */
     virtual AbstractByteArrayChecksumParameterSet* parameterSet() = 0;
+    virtual void loadConfig(const KConfigGroup& configGroup);
+    virtual void saveConfig(KConfigGroup& configGroup) const;
 
 public:
     QString name() const;
+    QString id() const;
 
 Q_SIGNALS: // TODO: add check for signal to tests
     void calculatedBytes(int bytes) const;
