@@ -35,9 +35,6 @@ public: // QAbstractItemDelegate
     void setEditorData(QWidget* editor, const QModelIndex& index) const override;
     void setModelData(QWidget* editor, QAbstractItemModel* model, const QModelIndex& index) const override;
 
-public: // QStyledItemDelegate API
-    QString displayText(const QVariant& value, const QLocale& locale) const override;
-
 private Q_SLOTS:
     void onEditorDone();
     void onReadOnlyChanged(bool isReadOnly) const;
