@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Kasten module, made within the KDE community.
 
-    SPDX-FileCopyrightText: 2009 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2009, 2023 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -10,6 +10,7 @@
 #define KASTEN_UINT16_HPP
 
 // Qt
+#include <QLocale>
 #include <QMetaType>
 #include <QString>
 
@@ -26,6 +27,7 @@ public:
 
 public:
     QString toString(bool asHex) const;
+    QString toString(bool asHex, const QLocale& locale) const;
 
 public:
     quint16 value = 0;
@@ -40,6 +42,12 @@ inline QString UInt16::toString(bool asHex) const
                    QString::number(value);
 }
 
+inline QString UInt16::toString(bool asHex, const QLocale& locale) const
+{
+    return asHex ? QStringLiteral("0x%1").arg(value, 4, 16, QChar::fromLatin1('0')) :
+                   locale.toString(value);
+}
+
 Q_DECLARE_METATYPE(UInt16)
 
 #endif
