@@ -10,7 +10,7 @@
 #define KASTEN_STRUCTURESTOOLVIEWFACTORY_HPP
 
 // lib
-#include <kasten/okteta/oktetakastencontrollers_export.hpp>
+#include "oktetakastencontrollers_export.hpp"
 // Kasten gui
 #include <Kasten/AbstractToolViewFactory>
 
@@ -20,10 +20,13 @@ class OKTETAKASTENCONTROLLERS_EXPORT StructuresToolViewFactory : public Abstract
 {
 public:
     StructuresToolViewFactory();
+    StructuresToolViewFactory(const StructuresToolViewFactory&) = delete;
+
     ~StructuresToolViewFactory() override;
 
-public:
-    // AbstractToolViewFactory API
+    StructuresToolViewFactory& operator=(const StructuresToolViewFactory&) = delete;
+
+public: // AbstractToolViewFactory API
     AbstractToolView* create(AbstractTool* tool) const override;
 
     QString iconName() const override;
