@@ -271,7 +271,7 @@ void StructureView::onLockButtonToggled(bool structureLocked)
 void StructureView::selectBytesInView()
 {
     auto* action = static_cast<QAction*>(sender());
-    const QModelIndex index = action->data().value<QModelIndex>();
+    const QModelIndex index = action->data().toModelIndex();
 
     mTool->selectBytesInView(index);
 }
@@ -279,7 +279,7 @@ void StructureView::selectBytesInView()
 void StructureView::copyToClipboard()
 {
     auto* action = static_cast<QAction*>(sender());
-    const QModelIndex index = action->data().value<QModelIndex>();
+    const QModelIndex index = action->data().toModelIndex();
     QMimeData* mimeData = mStructTreeView->model()->mimeData({index});
 
     QApplication::clipboard()->setMimeData(mimeData);
