@@ -11,6 +11,8 @@
 
 #include <QStyledItemDelegate>
 
+namespace Kasten {
+
 class StructureViewItemDelegate : public QStyledItemDelegate
 {
     Q_OBJECT
@@ -25,8 +27,8 @@ public: // QStyledItemDelegate API
     void setEditorData(QWidget* editor, const QModelIndex& index) const override;
     QWidget* createEditor(QWidget* parent,
                           const QStyleOptionViewItem& option, const QModelIndex& index) const override;
-    QSize sizeHint(const QStyleOptionViewItem& option,
-                   const QModelIndex& index) const override;
 };
 
+}
+
 #endif
