@@ -37,7 +37,7 @@ ViewProfilesManageController::ViewProfilesManageController(KXMLGUIClient* guiCli
 
 void ViewProfilesManageController::setTargetModel(AbstractModel* model)
 {
-    Q_UNUSED(model);
+    Q_UNUSED(model)
 }
 
 void ViewProfilesManageController::manageProfiles()
