@@ -132,12 +132,17 @@ void ViewStatusController::fixWidths(int offsetCoding)
 
 void ViewStatusController::setTargetModel(AbstractModel* model)
 {
+    ByteArrayView* const byteArrayView = model ? model->findBaseModel<ByteArrayView*>() : nullptr;
+    if (byteArrayView == mByteArrayView) {
+        return;
+    }
+
     if (mByteArrayView) {
         mByteArrayView->disconnect(this);
         mByteArrayView->disconnect(mOverwriteModeToggleButton);
     }
 
-    mByteArrayView = model ? model->findBaseModel<ByteArrayView*>() : nullptr;
+    mByteArrayView = byteArrayView;
 
     const bool hasView = (mByteArrayView != nullptr);
     if (hasView) {
