@@ -34,7 +34,7 @@ ExternalBookmarkStorage::~ExternalBookmarkStorage() = default;
 void ExternalBookmarkStorage::readBookmarks(ByteArrayDocument* document, const QUrl& url)
 {
     Okteta::AbstractByteArrayModel* byteArray = document->content();
-    Okteta::Bookmarkable* bookmarkable = qobject_cast<Okteta::Bookmarkable*>(byteArray);
+    auto* bookmarkable = qobject_cast<Okteta::Bookmarkable*>(byteArray);
 
     bookmarkable->removeAllBookmarks();
 
@@ -73,7 +73,7 @@ void ExternalBookmarkStorage::readBookmarks(ByteArrayDocument* document, const Q
 void ExternalBookmarkStorage::writeBookmarks(ByteArrayDocument* document, const QUrl& url)
 {
     Okteta::AbstractByteArrayModel* byteArray = document->content();
-    Okteta::Bookmarkable* bookmarkable = qobject_cast<Okteta::Bookmarkable*>(byteArray);
+    auto* bookmarkable = qobject_cast<Okteta::Bookmarkable*>(byteArray);
 
     if (!bookmarkable) {
         return;
