@@ -22,11 +22,11 @@
 
 namespace Kasten {
 
-static const QString DefaultSeparator = QStringLiteral(" ");
+// C++11 needs a definition for static constexpr members
+constexpr char ByteArrayValuesStreamEncoder::ConfigGroupId[];
+constexpr char ValuesStreamEncoderSettings::SeparatorConfigKey[];
 
-static constexpr char ByteArrayValuesStreamEncoderConfigGroupId[] = "ByteArrayValuesStreamEncoder";
-
-static constexpr char SeparatorConfigKey[] = "Separator";
+const QString ValuesStreamEncoderSettings::DefaultSeparator = QStringLiteral(" ");
 
 ValuesStreamEncoderSettings::ValuesStreamEncoderSettings() = default;
 
@@ -50,7 +50,7 @@ void ValuesStreamEncoderSettings::saveConfig(KConfigGroup& configGroup) const
 ByteArrayValuesStreamEncoder::ByteArrayValuesStreamEncoder()
     : AbstractByteArrayStreamEncoder(i18nc("name of the encoding target", "Values"), QStringLiteral("text/plain"))
 {
-    const KConfigGroup configGroup(KSharedConfig::openConfig(), ByteArrayValuesStreamEncoderConfigGroupId);
+    const KConfigGroup configGroup(KSharedConfig::openConfig(), ConfigGroupId);
     mSettings.loadConfig(configGroup);
 }
 
@@ -63,7 +63,7 @@ void ByteArrayValuesStreamEncoder::setSettings(const ValuesStreamEncoderSettings
     }
 
     mSettings = settings;
-    KConfigGroup configGroup(KSharedConfig::openConfig(), ByteArrayValuesStreamEncoderConfigGroupId);
+    KConfigGroup configGroup(KSharedConfig::openConfig(), ConfigGroupId);
     mSettings.saveConfig(configGroup);
     emit settingsChanged();
 }
