@@ -22,6 +22,11 @@ namespace Kasten {
 
 class ValuesStreamEncoderSettings
 {
+private:
+    static constexpr char SeparatorConfigKey[] = "Separator";
+
+    static const QString DefaultSeparator;
+
 public:
     ValuesStreamEncoderSettings();
     ValuesStreamEncoderSettings(const ValuesStreamEncoderSettings&) = default;
@@ -47,6 +52,9 @@ class ByteArrayValuesStreamEncoder : public AbstractByteArrayStreamEncoder
 {
     Q_OBJECT
 
+private:
+    static constexpr char ConfigGroupId[] = "ByteArrayValuesStreamEncoder";
+
 public:
     ByteArrayValuesStreamEncoder();
     ~ByteArrayValuesStreamEncoder() override;
