@@ -18,11 +18,7 @@
 #include <KLocalizedString>
 #include <KActionCollection>
 #include <KActionMenu>
-#include <KStandardAction>
 #include <KXMLGUIClient>
-// Qt
-#include <QApplication>
-#include <QMimeData>
 
 namespace Kasten {
 
