@@ -24,8 +24,12 @@ class KASTENCONTROLLERS_EXPORT InsertControllerFactory : public AbstractXmlGuiCo
 public:
     explicit InsertControllerFactory(ModelCodecViewManager* modelCodecViewManager,
                                      ModelCodecManager* modelCodecManager);
+    InsertControllerFactory(const InsertControllerFactory&) = delete;
+
     ~InsertControllerFactory() override;
 
+    InsertControllerFactory& operator=(const InsertControllerFactory&) = delete;
+
 public: // AbstractXmlGuiControllerFactory API
     AbstractXmlGuiController* create(KXMLGUIClient* guiClient) const override;
 
