@@ -23,8 +23,8 @@
 namespace Kasten {
 
 // same as ZoomSlider
-static constexpr double DefaultZoomControllerZoomOutLevelsSize = 49;
-static constexpr double DefaultZoomControllerZoomInLevelsSize = 50;
+static constexpr int DefaultZoomControllerZoomOutLevelsSize = 49;
+static constexpr int DefaultZoomControllerZoomInLevelsSize = 50;
 
 ZoomController::ZoomController(KXMLGUIClient* guiClient)
 {
@@ -73,11 +73,16 @@ ZoomController::ZoomController(KXMLGUIClient* guiClient)
 
 void ZoomController::setTargetModel(AbstractModel* model)
 {
+    AbstractModel* const zoomableModel = model ? model->findBaseModelWithInterface<If::Zoomable*>() : nullptr;
+    if (zoomableModel == mModel) {
+        return;
+    }
+
     if (mModel) {
         mModel->disconnect(this);
     }
 
-    mModel = model ? model->findBaseModelWithInterface<If::Zoomable*>() : nullptr;
+    mModel = zoomableModel;
     mZoomControl = mModel ? qobject_cast<If::Zoomable*>(mModel) : nullptr;
     m_zoomLevelsControl = nullptr;
 
