@@ -27,8 +27,8 @@ namespace Kasten {
 
 static constexpr int ZoomSliderWidth = 150;
 
-static constexpr double DefaultZoomSliderZoomOutLevelsSize = 49;
-static constexpr double DefaultZoomSliderZoomInLevelsSize = 50;
+static constexpr int DefaultZoomSliderZoomOutLevelsSize = 49;
+static constexpr int DefaultZoomSliderZoomInLevelsSize = 50;
 
 // TODO: look at Dolphin/Krita/KOffice zoom tool
 
@@ -83,11 +83,16 @@ ZoomSlider::~ZoomSlider() = default;
 
 void ZoomSlider::setTargetModel(AbstractModel* model)
 {
+    AbstractModel* const zoomableModel = model ? model->findBaseModelWithInterface<If::Zoomable*>() : nullptr;
+    if (zoomableModel == mModel) {
+        return;
+    }
+
     if (mModel) {
         mModel->disconnect(this);
     }
 
-    mModel = model ? model->findBaseModelWithInterface<If::Zoomable*>() : nullptr;
+    mModel = zoomableModel;
     mZoomControl = mModel ? qobject_cast<If::Zoomable*>(mModel) : nullptr;
     m_zoomLevelsControl = nullptr;
 
