@@ -10,8 +10,8 @@
 #define KASTEN_DOCUMENTVERSIONDATA_HPP
 
 // lib
-#include <kasten/kastencore_export.hpp>
-#include <kasten/documentversionid.hpp>
+#include "kastencore_export.hpp"
+#include "documentversionid.hpp"
 // Qt
 #include <QString>
 
@@ -21,7 +21,10 @@ class KASTENCORE_EXPORT DocumentVersionData
 {
 public:
     DocumentVersionData(DocumentVersionId id, const QString& changeComment);
-    DocumentVersionData() = delete;
+    DocumentVersionData(const DocumentVersionData&) = default;
+    ~DocumentVersionData() = default;
+
+    DocumentVersionData& operator=(const DocumentVersionData&) = default;
 
 public:
     DocumentVersionId id() const;
