@@ -17,10 +17,12 @@ class AbstractExportJobPrivate
 {
 public:
     explicit AbstractExportJobPrivate(AbstractExportJob* parent);
-    AbstractExportJobPrivate() = delete;
+    AbstractExportJobPrivate(const AbstractExportJobPrivate&) = delete;
 
     virtual ~AbstractExportJobPrivate();
 
+    AbstractExportJobPrivate& operator=(const AbstractExportJobPrivate&) = delete;
+
 public:
     AbstractDocument* document() const;
     void setDocument(AbstractDocument* document);
